@@ -108,12 +108,14 @@ void Config::populate(const ptree &tree) {
     mysql.database = tree.get("mysql.database", string("trojan"));
     mysql.username = tree.get("mysql.username", string("trojan"));
     mysql.password = tree.get("mysql.password", string());
-    mysql.cafile = tree.get("mysql.cafile", string());
+    mysql.key = tree.get("mysql.key", string());
+    mysql.cert = tree.get("mysql.cert", string());
+    mysql.ca = tree.get("mysql.ca", string());
 }
 
 bool Config::sip003() {
     char *JSON = getenv("SS_PLUGIN_OPTIONS");
-    if (JSON == NULL) {
+    if (JSON == nullptr) {
         return false;
     }
     populate(JSON);
@@ -125,7 +127,6 @@ bool Config::sip003() {
         case CLIENT:
         case NAT:
             throw runtime_error("SIP003 with wrong run_type");
-            break;
         case FORWARD:
             remote_addr = getenv("SS_REMOTE_HOST");
             remote_port = atoi(getenv("SS_REMOTE_PORT"));
@@ -141,10 +142,10 @@ string Config::SHA224(const string &message) {
     char mdString[(EVP_MAX_MD_SIZE << 1) + 1];
     unsigned int digest_len;
     EVP_MD_CTX *ctx;
-    if ((ctx = EVP_MD_CTX_new()) == NULL) {
+    if ((ctx = EVP_MD_CTX_new()) == nullptr) {
         throw runtime_error("could not create hash context");
     }
-    if (!EVP_DigestInit_ex(ctx, EVP_sha224(), NULL)) {
+    if (!EVP_DigestInit_ex(ctx, EVP_sha224(), nullptr)) {
         EVP_MD_CTX_free(ctx);
         throw runtime_error("could not initialize hash context");
     }
