@@ -79,7 +79,9 @@ public:
         std::string database;
         std::string username;
         std::string password;
-        std::string cafile;
+        std::string key;
+        std::string cert;
+        std::string ca;
     } mysql;
     void load(const std::string &filename);
     void populate(const std::string &JSON);
