@@ -53,8 +53,8 @@ private:
     void udp_sent();
 public:
     ServerSession(const Config &config, boost::asio::io_context &io_context, boost::asio::ssl::context &ssl_context, Authenticator *auth, const std::string &plain_http_response);
-    boost::asio::ip::tcp::socket& accept_socket();
-    void start();
+    boost::asio::ip::tcp::socket& accept_socket() override;
+    void start() override;
 };
 
 #endif // _SERVERSESSION_H_
