@@ -45,9 +45,9 @@ private:
     void out_sent();
     void timer_async_wait();
 public:
-    UDPForwardSession(const Config &config, boost::asio::io_context &io_context, boost::asio::ssl::context &ssl_context, const boost::asio::ip::udp::endpoint &endpoint, const UDPWrite &in_write);
-    boost::asio::ip::tcp::socket& accept_socket();
-    void start();
+    UDPForwardSession(const Config &config, boost::asio::io_context &io_context, boost::asio::ssl::context &ssl_context, const boost::asio::ip::udp::endpoint &endpoint, UDPWrite in_write);
+    boost::asio::ip::tcp::socket& accept_socket() override;
+    void start() override;
     bool process(const boost::asio::ip::udp::endpoint &endpoint, const std::string &data);
 };
 
