@@ -32,8 +32,8 @@ void SSLSession::remove_session_cb(SSL_CTX*, SSL_SESSION *session) {
 }
 
 SSL_SESSION *SSLSession::get_session() {
-    if (sessions.size() == 0) {
-        return NULL;
+    if (sessions.empty()) {
+        return nullptr;
     }
     return sessions.front();
 }
